#line 2 "src/conf_lex.c"

#line 4 "src/conf_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer conf_create_buffer
#define yy_delete_buffer conf_delete_buffer
#define yy_scan_buffer conf_scan_buffer
#define yy_scan_string conf_scan_string
#define yy_scan_bytes conf_scan_bytes
#define yy_init_buffer conf_init_buffer
#define yy_flush_buffer conf_flush_buffer
#define yy_load_buffer_state conf_load_buffer_state
#define yy_switch_to_buffer conf_switch_to_buffer
#define yypush_buffer_state confpush_buffer_state
#define yypop_buffer_state confpop_buffer_state
#define yyensure_buffer_stack confensure_buffer_stack
#define yy_flex_debug conf_flex_debug
#define yyin confin
#define yyleng confleng
#define yylex conflex
#define yylineno conflineno
#define yyout confout
#define yyrestart confrestart
#define yytext conftext
#define yywrap confwrap
#define yyalloc confalloc
#define yyrealloc confrealloc
#define yyfree conffree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define conf_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer conf_create_buffer
#endif

#ifdef yy_delete_buffer
#define conf_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer conf_delete_buffer
#endif

#ifdef yy_scan_buffer
#define conf_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer conf_scan_buffer
#endif

#ifdef yy_scan_string
#define conf_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string conf_scan_string
#endif

#ifdef yy_scan_bytes
#define conf_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes conf_scan_bytes
#endif

#ifdef yy_init_buffer
#define conf_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer conf_init_buffer
#endif

#ifdef yy_flush_buffer
#define conf_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer conf_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define conf_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state conf_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define conf_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer conf_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define confpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state confpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define confpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state confpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define confensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack confensure_buffer_stack
#endif

#ifdef yylex
#define conflex_ALREADY_DEFINED
#else
#define yylex conflex
#endif

#ifdef yyrestart
#define confrestart_ALREADY_DEFINED
#else
#define yyrestart confrestart
#endif

#ifdef yylex_init
#define conflex_init_ALREADY_DEFINED
#else
#define yylex_init conflex_init
#endif

#ifdef yylex_init_extra
#define conflex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra conflex_init_extra
#endif

#ifdef yylex_destroy
#define conflex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy conflex_destroy
#endif

#ifdef yyget_debug
#define confget_debug_ALREADY_DEFINED
#else
#define yyget_debug confget_debug
#endif

#ifdef yyset_debug
#define confset_debug_ALREADY_DEFINED
#else
#define yyset_debug confset_debug
#endif

#ifdef yyget_extra
#define confget_extra_ALREADY_DEFINED
#else
#define yyget_extra confget_extra
#endif

#ifdef yyset_extra
#define confset_extra_ALREADY_DEFINED
#else
#define yyset_extra confset_extra
#endif

#ifdef yyget_in
#define confget_in_ALREADY_DEFINED
#else
#define yyget_in confget_in
#endif

#ifdef yyset_in
#define confset_in_ALREADY_DEFINED
#else
#define yyset_in confset_in
#endif

#ifdef yyget_out
#define confget_out_ALREADY_DEFINED
#else
#define yyget_out confget_out
#endif

#ifdef yyset_out
#define confset_out_ALREADY_DEFINED
#else
#define yyset_out confset_out
#endif

#ifdef yyget_leng
#define confget_leng_ALREADY_DEFINED
#else
#define yyget_leng confget_leng
#endif

#ifdef yyget_text
#define confget_text_ALREADY_DEFINED
#else
#define yyget_text confget_text
#endif

#ifdef yyget_lineno
#define confget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno confget_lineno
#endif

#ifdef yyset_lineno
#define confset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno confset_lineno
#endif

#ifdef yywrap
#define confwrap_ALREADY_DEFINED
#else
#define yywrap confwrap
#endif

#ifdef yyalloc
#define confalloc_ALREADY_DEFINED
#else
#define yyalloc confalloc
#endif

#ifdef yyrealloc
#define confrealloc_ALREADY_DEFINED
#else
#define yyrealloc confrealloc
#endif

#ifdef yyfree
#define conffree_ALREADY_DEFINED
#else
#define yyfree conffree
#endif

#ifdef yytext
#define conftext_ALREADY_DEFINED
#else
#define yytext conftext
#endif

#ifdef yyleng
#define confleng_ALREADY_DEFINED
#else
#define yyleng confleng
#endif

#ifdef yyin
#define confin_ALREADY_DEFINED
#else
#define yyin confin
#endif

#ifdef yyout
#define confout_ALREADY_DEFINED
#else
#define yyout confout
#endif

#ifdef yy_flex_debug
#define conf_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug conf_flex_debug
#endif

#ifdef yylineno
#define conflineno_ALREADY_DEFINED
#else
#define yylineno conflineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 78
#define YY_END_OF_BUFFER 79
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[505] =
    {   0,
        0,    3,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   79,   77,   78,    3,    3,    2,
       77,    3,   31,   76,   77,   77,    4,   65,    6,   64,
       77,   77,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   13,   30,    9,   10,   12,   11,
       77,    8,   68,   73,   70,   70,   72,   71,   77,   66,
       75,   74,   77,   77,   77,   77,    3,    3,    2,    0,
        3,    3,    1,    0,   31,   76,    7,    4,   65,   64,
        5,    0,   63,   63,   63,   63,   63,   63,   63,   63,

       63,   63,   63,   63,   63,   63,   13,   30,   30,    9,
        0,    8,    8,   68,   73,    0,   69,   72,   71,    0,
       66,   66,   74,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,    0,    0,    0,    0,   17,    0,
        0,    0,   16,    0,    0,    0,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   63,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   67,    0,    0,    0,    0,   23,    0,

        0,    0,    0,    0,    0,    0,    0,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,    0,
       20,    0,    0,   24,   21,    0,    0,    0,    0,   15,
        0,   63,   63,   63,   38,   63,   63,   63,   63,   63,
       63,   49,   63,   18,    0,   14,   25,   22,    0,    0,
        0,   63,   63,   63,   33,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   19,   26,   27,    0,   63,   63,   63,   63,   63,
       50,   63,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   63,    0,   63,   63,   63,   63,

       63,   63,   63,   58,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   52,   63,   63,   63,   28,   63,
       63,   63,   63,   63,   32,   63,   63,   62,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   59,   63,
       63,    0,   63,   63,   63,   63,   63,   35,   34,   63,
       65,   63,   63,   63,   63,   63,   44,   55,   63,   63,
       63,    0,   63,   63,   63,   63,   63,   56,   54,   63,
       63,   43,   63,   63,   63,   63,   63,    0,   63,   63,
       60,   63,   36,   63,   63,   39,   63,   63,   63,   63,
        0,   63,   63,   63,   63,   63,   63,   63,   63,   63,

       63,   63,   63,    0,   63,   63,   63,   63,   63,   63,
       63,   65,   63,   63,   63,   63,    0,   63,   63,   63,
       63,   63,   63,   63,   65,   63,   63,   40,   63,   29,
       63,   63,   63,   63,   48,   63,   63,   65,   63,   63,
       37,   63,   63,   63,   63,   63,   63,   65,   63,   63,
       63,   63,   63,   53,   63,   63,   65,   63,   63,   42,
       63,   51,   63,   63,   65,   63,   63,   63,   63,   63,
       65,   63,   63,   63,   63,   63,   57,   63,   63,   63,
       63,   63,   63,   41,   63,   45,   63,   63,   63,   63,
       63,   63,   47,   46,   63,   63,   63,   63,   63,   63,

       63,   63,   61,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    1,    7,    1,    8,    1,    1,    1,
        1,    1,    9,   10,   11,    1,   12,   13,   14,   15,
       13,   13,   13,   16,   13,   13,   13,    1,    1,    1,
       17,   18,    1,   19,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
        1,   21,    1,    1,   22,    1,   23,   24,   25,   26,

       27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,   48,   49,    1,   50,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    8,    8,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    8,    1,    1,    1,    1,    1,    8,
        1,    1,    8,    1,    1,    1,    1,    8,    8,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    8,    1,    1,    1,    1,
        1,    8,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[51] =
    {   0,
        1,    2,    3,    3,    2,    1,    1,    4,    1,    1,
        1,    1,    5,    5,    5,    5,    1,    6,    2,    5,
        2,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    1,    1
    } ;

static const flex_int16_t yy_base[523] =
    {   0,
     1052,    0,    7,    0,   57,  107,  157,    0,  207,  257,
       67,   76,   83,  118,  127,  131,  218,  227,   86,  137,
       92,   96,  268,  282, 1054, 1056, 1056,    0,  231, 1056,
     1050,   79,  142, 1056, 1049, 1039,    0,    0, 1056,  219,
     1038, 1030,  306,  319,  332, 1011, 1024,   25, 1009, 1002,
       78, 1001, 1016, 1019,    0,  229,    0, 1056, 1056, 1056,
      138, 1036,    0,  245, 1021,  260,  247,  249,  272, 1034,
     1056,  270, 1011,  991,  999,  998,    0,  298, 1056, 1031,
      279,  287, 1056, 1030,  291, 1056, 1056,    0,    0,  289,
     1056,  324,  345,    0,  998,  995,  988,  992,  997,  998,

      991,  987,  987,  988,  982,  981,    0,  315,  358,    0,
      275, 1015, 1014,    0,  308,  969, 1056,  361,  373,  319,
     1012, 1011,  374,  987,  983,  972,  970,  984,  115,  117,
      974,  987,  986,  979,  983,  962,  966,  981,  980,  964,
      958,  964,  974,  961,    0,  965,  954,  952, 1056,  965,
      951,  965,  351,  965,  963,  957,  375,  956,  962,  947,
      962,  219,  280,  943,  960,  958,  943,  957,  928,  941,
      934,  939,  943,  946,  941,  944,  933,  312,  935,  941,
      931,  320,  937,  942,  937,  189,  357,  332,  921,  250,
      922,  920,  356, 1056,  933,  918,  935,  921, 1056,  928,

      927,  913,  926,  915,  908,  922,  924,  301,  926,  906,
      920,  361,  350,  360,  923,  362,  913,  916,  372,  916,
     1056,  906,  913, 1056, 1056,  897,  910,  896,  910, 1056,
      901,  365,  378,  907,    0,  368,  380,  376,  400,  383,
      885,    0,  326, 1056,  905, 1056, 1056, 1056,  889,  903,
      886,   91,  385,  391,  906,  377,  281,  406,  394,  402,
      408,  409,  411,  419,  413,  414,  416,  418,  425,  900,
      430, 1056, 1056, 1056,  900,  427,  433,  428,  442,  434,
      889,  431,  436,  439,  441,  445,  450,  888,  446,  453,
      456,  459,  463,  901,  466,  895,  462,  472,  464,  475,

      885,  476,  470,  884,  468,  480,  483,  491,  490,  485,
      486,  493,  497,  495,  883,  496,  509,  499,  896,  505,
      510,  508,  511,  512,  881,  513,  514,  880,  879,  524,
      521,  526,  528,  523,  527,  532,  529,  546,  878,  540,
      536,  872,  876,  551,  538,  555,  544,  875,  874,  552,
      893,  545,  563,  550,  562,  566,  872,  871,  554,  572,
      561,  879,  567,  565,  869,  569,  570,  868,    0,  580,
      586,  867,  587,  590,  583,  866,  581,  859,  596,  597,
      864,  594,  863,  598,  589,  862,  612,  592,  600,  607,
      870,  613,  606,  608,  623,  611,  625,  624,  328,  628,

      629,  630,  860,  859,  626,  858,  635,  636,  633,  642,
      647,  860,  639,  654,  641,  648,  843,  651,  657,  660,
      833,  653,  661,  821,  776,  655,  670,  780,  662, 1056,
      665,  664,  679,  673,  778,  682,  676,  787,  675,  680,
      767,  677,  766,  681,  684,  699,  695,  740,  697,  702,
      691,  692,  706,  722,  707,  708,  638,  711,  591,  519,
      712,  482,  704,  719,  397,  723,  720,  716,  718,  727,
      376,  728,  726,  725,  729,  730,    0,  732,  734,  737,
      735,  742,  743,  344,  750,  263,  747,  752,  755,  753,
      754,  757,  204,   56,  769,  771,  776,  764,  765,  775,

      779,  777,   41, 1056,  818,  824,  830,  836,  842,  848,
      854,  860,  866,  869,  871,  873,  875,  877,    1,  879,
      885,  888
    } ;

static const flex_int16_t yy_def[523] =
    {   0,
      505,  506,  504,    3,  507,  507,  504,    7,  508,  508,
      505,  505,  509,  509,  509,  509,  509,  509,  505,  505,
      510,  510,  505,  505,  504,  504,  504,  511,  511,  504,
      504,  512,  504,  504,  504,  504,  513,  514,  504,  515,
      504,  504,  516,  517,  517,   45,   45,   45,   45,   45,
       45,   45,   45,   45,  518,  519,  520,  504,  504,  504,
      504,  504,  521,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  511,  511,  504,  504,
      512,  512,  504,  504,  504,  504,  504,  513,  514,  515,
      504,  504,  516,   45,   45,   45,   45,   45,   45,   45,

       45,   45,   45,   45,   45,   45,  518,  519,  519,  520,
      504,  504,  504,  521,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,  522,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  516,   45,   45,   45,
       45,  157,  157,   45,   45,   45,   45,   45,  522,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  157,   45,   45,   45,  157,  157,  157,   45,  157,
       45,   45,  157,  504,  504,  504,  504,  504,  504,  504,

      504,  504,  504,  504,  504,  504,  504,  157,   45,   45,
       45,  157,  157,  157,   45,  157,   45,   45,  157,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  157,  157,   45,   45,  157,  157,  157,  157,  157,
       45,   45,  157,  504,  504,  504,  504,  504,  504,  504,
      504,  157,  157,  157,   45,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,   45,
      157,  504,  504,  504,  504,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,   45,  157,  504,  157,  157,  157,  157,

      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  504,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  504,  157,  157,  157,  157,  157,  157,  157,  157,
      514,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  504,  157,  157,  157,  157,  157,  157,  514,  157,
      157,  157,  157,  157,  157,  157,  157,  504,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      504,  157,  157,  157,  157,  157,  157,  157,  157,  157,

      157,  157,  157,  504,  157,  157,  157,  157,  157,  157,
      157,  514,  157,  157,  157,  157,  504,  157,  157,  157,
      157,  157,  157,  157,  514,  157,  157,  157,  157,  504,
      157,  157,  157,  157,  157,  157,  157,  514,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  514,  157,  157,
      157,  157,  157,  157,  157,  157,  514,  157,  157,  157,
      157,  157,  157,  157,  514,  157,  157,  157,  157,  157,
      514,  157,  157,  157,  157,  157,  514,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,

      157,  157,  157,    0,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504
    } ;

static const flex_int16_t yy_nxt[1107] =
    {   0,
      504,   29,   30,   31,   29,  109,   32,   26,   33,   34,
       35,   33,   36,   37,   38,   26,   26,   26,   39,   40,
       40,   40,   40,   41,   26,   42,   40,   26,   43,   44,
       45,   46,   47,   45,   45,   48,   45,   45,   45,   45,
       49,   45,   50,   45,   45,   45,   51,   52,   45,   45,
       53,   54,   45,   45,   45,   26,   26,   26,   33,   34,
       35,   33,   26,   26,   98,   26,   26,   26,   26,   34,
       35,   61,   99,   26,   26,   26,   93,   26,   34,   35,
       61,   83,   84,   62,   64,   34,   35,   64,   34,   35,
       69,   93,   62,   72,   34,   35,   72,   72,   34,   35,

       72,   65,   70,   66,  102,   26,   26,   26,   33,   34,
       35,   33,   26,   26,  103,   26,   26,   26,   26,   64,
       34,   35,   64,   26,   26,   26,   93,   26,   67,   34,
       35,   67,   67,   34,   35,   67,   65,  276,   66,   34,
       35,   69,  111,   85,  153,   65,   85,   66,  151,   65,
      152,   66,  154,   70,  112,   26,   26,   26,   33,   34,
       35,   33,   26,   26,   26,   26,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   56,   26,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,

       56,   56,   56,   56,   56,   26,   26,   26,   33,   34,
       35,   33,   26,   26,  212,   58,   59,   60,   26,   68,
       34,   35,   68,   26,   93,   26,   89,   26,   68,   34,
       35,   68,   78,   79,   80,   78,   65,   81,   66,   93,
       89,  108,  108,  108,  108,   65,  115,   66,  118,  115,
      119,  118,  187,  119,   93,   26,   26,   26,   33,   34,
       35,   33,   26,   26,  117,   58,   59,   60,   26,   33,
       27,  123,   33,   26,  123,   26,  120,   26,  117,  111,
      117,   83,   84,   33,   27,   93,   33,  216,  121,   83,
       84,  112,   85,   73,   74,   85,   89,   75,   93,   78,

       79,   80,   78,   76,   81,   26,   26,   73,   74,  115,
       89,   75,  115,   89,  281,   93,   93,   76,   89,   89,
       89,   89,  232,  120,  188,   89,   89,  108,  108,  108,
      108,   90,   90,   90,   90,  121,   93,  203,   90,   89,
       93,  204,  412,   95,   90,   90,   90,   90,  271,  128,
      129,   90,   89,   93,  130,   93,  208,   89,   89,   89,
       89,   93,  118,   93,   89,  118,  131,   93,  214,  132,
      108,  108,  108,  108,  119,  123,  176,  119,  123,   93,
      177,  219,   89,  213,  236,   93,  178,   89,   89,   89,
       89,   93,   93,  237,   89,   93,   93,   93,  243,  238,

       93,  240,  253,   93,  256,  252,  257,   93,  258,  269,
      182,   93,   93,   93,  277,   93,  477,  278,   93,  280,
       93,  254,  259,  260,  284,  261,   93,  262,  263,   93,
      264,  283,  282,  265,  285,   93,  471,   93,  266,  289,
      267,   93,  268,   93,   93,  286,   93,  288,   93,   93,
      287,   93,  293,   93,   93,  295,  290,  292,  291,  298,
       93,  297,   93,   93,  300,   93,   93,  299,   93,   93,
      305,   93,  301,  306,   93,  304,   93,  302,  303,  307,
       93,   93,  308,  313,  309,   93,  310,  318,   93,  312,
      314,   93,  315,  316,   93,  320,  321,   93,   93,   93,

      323,   93,  326,   93,  322,   93,  329,   93,  328,  330,
       93,   93,  327,  331,  332,   93,  324,   93,   93,  336,
       93,   93,  335,  337,  333,   93,   93,  334,   93,  338,
       93,   93,   93,  340,   93,  343,  346,  351,  345,  341,
       93,  339,  344,   93,   93,   93,   93,   93,   93,   93,
      354,  352,  353,  347,   93,  349,   93,  348,   93,   93,
      355,   93,   93,   93,   93,  357,  356,   93,  359,  360,
      358,   93,  364,   93,  365,   93,  366,  368,  370,   93,
       93,   93,  361,  367,  371,   93,   93,   93,  373,   93,
       93,  372,  374,  375,  376,  377,   93,   93,   93,  379,

       93,   93,   93,  382,   93,   93,  384,   93,  385,  380,
      383,  387,  386,  388,  390,   93,   93,  392,   93,  393,
      394,   93,   93,  395,   93,   93,  467,   93,  402,   93,
      396,   93,   93,   93,  397,   93,  398,  403,  399,  401,
      405,   93,   93,   93,  408,  406,   93,   93,   93,  407,
      410,  400,  409,  411,  413,  414,  415,  420,   93,   93,
       93,   93,  418,   93,   93,   93,  421,  423,   93,  424,
       93,   93,  422,  426,   93,  427,   93,   93,  432,  465,
      429,  428,   93,   93,  431,  433,   93,  436,   93,   93,
       93,  439,   93,  435,  440,   93,   93,   93,  442,   93,

       93,  444,  441,  445,  447,   93,  443,  446,   93,  450,
       93,   93,   93,  451,   93,   93,   93,   93,  449,   93,
      455,  456,  453,  458,  459,  454,   93,   93,  462,  463,
       93,  461,   93,  464,   93,  460,  466,   93,  468,   93,
      470,   93,   93,   93,  472,  469,   93,   93,  473,  476,
      478,   93,  479,   93,   93,   93,  474,   93,   93,  475,
       93,   93,   93,   93,   93,   93,  480,   93,  481,   93,
       93,  482,   93,  483,  484,  486,  485,   93,   93,  492,
      489,  457,   93,  487,  488,   93,  490,   93,   93,   93,
       93,  491,   93,  493,  494,  496,  497,  498,  495,   93,

       93,  452,   93,  499,   93,  502,   93,  500,  501,  448,
       93,   93,   93,   93,   93,   93,  438,  503,   26,   26,
       26,   26,   26,   26,   28,   28,   28,   28,   28,   28,
       55,   55,   55,   55,   55,   55,   57,   57,   57,   57,
       57,   57,   63,   63,   63,   63,   63,   63,   71,   71,
       71,   71,   71,   71,   77,   77,  437,   77,   77,   77,
       82,   82,   82,   82,   82,   82,   88,   88,  434,   88,
       88,   88,   89,   89,   90,   90,   93,   93,   94,   94,
      107,  107,  110,  110,  110,  114,  430,  425,  114,  114,
      114,  169,  169,  419,  417,  416,  404,   93,   93,   93,

      391,  389,   93,   93,  381,  378,   93,   93,  369,   93,
       93,  363,  362,   93,  350,   93,   93,  342,   93,   93,
      325,  319,  317,  311,   93,  296,  294,  279,  275,  274,
      273,  272,  270,  255,  251,  250,  249,  248,  247,  246,
      245,  244,  242,  241,  239,  235,  234,  233,  231,  230,
      229,  228,  227,  226,  225,  224,  223,  222,  221,  220,
      218,  217,  215,  211,  210,  209,  207,  206,  205,  202,
      201,  200,  199,  198,  197,  196,  195,  194,  193,  192,
      191,  190,  189,  186,  185,  184,  183,  181,  180,  179,
      175,  174,  173,  172,  171,  170,  168,  167,  166,  165,

      164,  163,  162,  161,  160,  159,  158,  157,  156,  155,
      150,  149,  148,  147,  146,  122,  122,  145,  113,  113,
      144,  143,  142,  141,  140,  139,  138,  137,  136,  135,
      134,  133,   83,   79,  127,  126,  125,  124,  122,  116,
      113,  106,  105,  104,  101,  100,   97,   96,   92,   91,
       87,   86,   79,  504,   27,   25,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,

      504,  504,  504,  504,  504,  504
    } ;

static const flex_int16_t yy_chk[1107] =
    {   0,
        0,    2,    2,    2,    2,  519,    2,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    5,    5,    5,
        5,    5,    5,    5,   48,    5,    5,    5,    5,   11,
       11,   11,   48,    5,    5,    5,  503,    5,   12,   12,
       12,   32,   32,   11,   13,   13,   13,   13,   19,   19,
       19,  494,   12,   21,   21,   21,   21,   22,   22,   22,

       22,   13,   19,   13,   51,    5,    5,    6,    6,    6,
        6,    6,    6,    6,   51,    6,    6,    6,    6,   14,
       14,   14,   14,    6,    6,    6,  252,    6,   15,   15,
       15,   15,   16,   16,   16,   16,   14,  252,   14,   20,
       20,   20,   61,   33,  130,   15,   33,   15,  129,   16,
      129,   16,  130,   20,   61,    6,    6,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    9,    9,    9,
        9,    9,    9,    9,  186,    9,    9,    9,    9,   17,
       17,   17,   17,    9,  186,    9,   40,    9,   18,   18,
       18,   18,   29,   29,   29,   29,   17,   29,   17,  493,
       40,   56,   56,   56,   56,   18,   64,   18,   67,   64,
       68,   67,  162,   68,  162,    9,    9,   10,   10,   10,
       10,   10,   10,   10,   66,   10,   10,   10,   10,   23,
       23,   72,   23,   10,   72,   10,   69,   10,   66,  111,
       66,   81,   81,   24,   24,  190,   24,  190,   69,   82,
       82,  111,   85,   23,   23,   85,   90,   23,  486,   78,

       78,   78,   78,   23,   78,   10,   10,   24,   24,  115,
       90,   24,  115,   43,  257,  163,  257,   24,   43,   43,
       43,   43,  208,  120,  163,   43,   44,  108,  108,  108,
      108,   44,   44,   44,   44,  120,  208,  178,   44,   45,
       44,  178,  399,   44,   45,   45,   45,   45,  243,   92,
       92,   45,   93,   45,   92,  182,  182,   93,   93,   93,
       93,  243,  118,  399,   93,  118,   92,  188,  188,   92,
      109,  109,  109,  109,  119,  123,  153,  119,  123,  484,
      153,  193,  157,  187,  212,  213,  153,  157,  157,  157,
      157,  193,  187,  213,  157,  214,  212,  216,  219,  214,

      232,  216,  233,  236,  236,  232,  237,  219,  238,  240,
      157,  238,  256,  233,  253,  237,  471,  254,  240,  256,
      253,  233,  239,  239,  260,  239,  254,  239,  239,  259,
      239,  259,  258,  239,  261,  239,  465,  260,  239,  265,
      239,  258,  239,  261,  262,  262,  263,  264,  265,  266,
      263,  267,  269,  268,  264,  271,  266,  268,  267,  277,
      269,  276,  276,  278,  279,  271,  282,  278,  277,  280,
      282,  283,  279,  283,  284,  280,  285,  279,  279,  284,
      286,  289,  285,  290,  286,  287,  287,  295,  290,  289,
      291,  291,  292,  293,  292,  297,  298,  297,  293,  299,

      300,  295,  302,  305,  299,  303,  306,  298,  305,  307,
      300,  302,  303,  308,  309,  306,  300,  462,  307,  312,
      310,  311,  311,  313,  309,  309,  308,  310,  312,  314,
      314,  316,  313,  317,  318,  320,  323,  330,  322,  318,
      320,  316,  321,  322,  317,  321,  323,  324,  326,  327,
      333,  331,  332,  324,  460,  327,  331,  326,  334,  330,
      334,  332,  335,  333,  337,  336,  335,  336,  338,  340,
      337,  341,  344,  345,  345,  340,  346,  350,  352,  347,
      352,  338,  341,  347,  353,  354,  344,  350,  355,  359,
      346,  354,  356,  359,  360,  361,  361,  355,  353,  363,

      364,  356,  363,  366,  366,  367,  370,  360,  371,  364,
      367,  374,  373,  375,  377,  370,  377,  379,  375,  380,
      382,  371,  373,  384,  385,  374,  459,  388,  389,  382,
      385,  379,  380,  384,  387,  389,  387,  390,  387,  388,
      392,  393,  390,  394,  395,  393,  396,  387,  392,  394,
      397,  387,  396,  398,  400,  401,  402,  407,  395,  398,
      397,  405,  405,  400,  401,  402,  408,  410,  409,  411,
      407,  408,  409,  413,  413,  414,  415,  410,  419,  457,
      416,  415,  411,  416,  418,  420,  418,  423,  422,  414,
      426,  426,  419,  422,  427,  420,  423,  429,  431,  432,

      431,  433,  429,  434,  437,  427,  432,  436,  434,  440,
      439,  437,  442,  442,  433,  440,  444,  436,  439,  445,
      446,  447,  444,  449,  450,  445,  451,  452,  453,  455,
      447,  452,  449,  456,  446,  451,  458,  450,  461,  463,
      464,  453,  455,  456,  466,  463,  458,  461,  467,  470,
      472,  468,  473,  469,  464,  467,  468,  454,  466,  469,
      474,  473,  470,  472,  475,  476,  474,  478,  475,  479,
      481,  476,  480,  478,  479,  481,  480,  482,  483,  489,
      485,  448,  487,  482,  483,  485,  487,  488,  490,  491,
      489,  488,  492,  490,  491,  495,  496,  497,  492,  498,

      499,  443,  441,  498,  495,  501,  496,  499,  500,  438,
      500,  497,  502,  435,  501,  428,  425,  502,  505,  505,
      505,  505,  505,  505,  506,  506,  506,  506,  506,  506,
      507,  507,  507,  507,  507,  507,  508,  508,  508,  508,
      508,  508,  509,  509,  509,  509,  509,  509,  510,  510,
      510,  510,  510,  510,  511,  511,  424,  511,  511,  511,
      512,  512,  512,  512,  512,  512,  513,  513,  421,  513,
      513,  513,  514,  514,  515,  515,  516,  516,  517,  517,
      518,  518,  520,  520,  520,  521,  417,  412,  521,  521,
      521,  522,  522,  406,  404,  403,  391,  386,  383,  381,

      378,  376,  372,  368,  365,  362,  358,  357,  351,  349,
      348,  343,  342,  339,  329,  328,  325,  319,  315,  304,
      301,  296,  294,  288,  281,  275,  270,  255,  251,  250,
      249,  245,  241,  234,  231,  229,  228,  227,  226,  223,
      222,  220,  218,  217,  215,  211,  210,  209,  207,  206,
      205,  204,  203,  202,  201,  200,  198,  197,  196,  195,
      192,  191,  189,  185,  184,  183,  181,  180,  179,  177,
      176,  175,  174,  173,  172,  171,  170,  169,  168,  167,
      166,  165,  164,  161,  160,  159,  158,  156,  155,  154,
      152,  151,  150,  148,  147,  146,  144,  143,  142,  141,

      140,  139,  138,  137,  136,  135,  134,  133,  132,  131,
      128,  127,  126,  125,  124,  122,  121,  116,  113,  112,
      106,  105,  104,  103,  102,  101,  100,   99,   98,   97,
       96,   95,   84,   80,   76,   75,   74,   73,   70,   65,
       62,   54,   53,   52,   50,   49,   47,   46,   42,   41,
       36,   35,   31,   25,    1,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,

      504,  504,  504,  504,  504,  504
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "src/conf_lex.l"
#line 11 "src/conf_lex.l"

#define YYDEBUG 1

/*
 * AIDE (Advanced Intrusion Detection Environment)
 *
 * Copyright (C) 1999-2002, 2004-2006, 2010-2013, 2015-2016, 2019-2022
 *               Rami Lehti, Pablo Virolainen, Richard van den Berg,
 *               Hannes von Haugwitz
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "util.h"
#include "conf_yacc.h"
#include "errorcodes.h"
#include "commandconf.h"
#include "log.h"

#include "conf_ast.h"

#define LOG_LEX_TOKEN(log_level, token, text) \
    log_msg(log_level, "%s:%d: \u2502 " #token " (text: '%s')", conf_filename, conf_linenumber, text);

#define LOG_CONFIG_LINE(log_level, msg) \
     log_msg(log_level, "%s:%d: %s (line: '%s')", conf_filename, conf_linenumber, msg, conf_linebuf);

#define DEPRECATION_NOTICE(deprecated_option, new_option) \
     log_msg(LOG_LEVEL_NOTICE, "%s:%d: Using '%s' is DEPRECATED and will be removed in the release after next. Update your config and use '%s' instead (line: '%s')", conf_filename, conf_linenumber, deprecated_option, new_option ,conf_linebuf);
#define DEPRECATION_WARNING(deprecated_option, new_option) \
     log_msg(LOG_LEVEL_WARNING, "%s:%d: Using '%s' is DEPRECATED and will be removed in the next release.. Update your config and use '%s' instead (line: '%s')", conf_filename, conf_linenumber, deprecated_option, new_option ,conf_linebuf);

int conf_linenumber = 0;
char *conf_filename;
char *conf_linebuf;

LOG_LEVEL lex_log_level = LOG_LEVEL_CONFIG;

#define YY_INPUT(buf,result,max_size) \
        if( ((result=conf_input_wrapper(buf,max_size,confin)) == 0) \
            && ferror(yyin) ) \
          YY_FATAL_ERROR( "input in flex scanner failed" );

#line 1172 "src/conf_lex.c"
#define YY_NO_INPUT 1

#line 1175 "src/conf_lex.c"

#define INITIAL 0
#define CONFIG 1
#define DEFSTMT 2
#define ENVVAR 3
#define EXPR 4
#define EXPREQUHUNT 5
#define PATH 6
#define STRING 7
#define STRINGS 8
#define STRINGEQHUNT 9
#define STRINGHUNT 10
#define CONDITION 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 72 "src/conf_lex.l"

#line 1406 "src/conf_lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 505 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1056 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case YY_STATE_EOF(INITIAL):
#line 73 "src/conf_lex.l"
{
            log_msg(lex_log_level,"%s: - <end of file>", conf_filename);
            return (0);
           }
	YY_BREAK
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 77 "src/conf_lex.l"
{
            conf_linebuf = checked_strndup(conftext, confleng-1);
            ++conf_linenumber;
            LOG_CONFIG_LINE(lex_log_level, "- skip comment line")
            free(conf_linebuf);
           }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 83 "src/conf_lex.l"
{
            conf_linebuf = "";
            ++conf_linenumber;
            LOG_CONFIG_LINE(lex_log_level, "- skip empty line")
           }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 88 "src/conf_lex.l"
{
            conf_linebuf = checked_strndup(conftext, confleng);
            ++conf_linenumber;
            log_msg(lex_log_level,"%s:%d: \u252c '%s'", conf_filename, conf_linenumber, conf_linebuf);
            yyless(0);
            BEGIN(CONFIG);
           }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 95 "src/conf_lex.l"
{ /* inline comment */
  LOG_LEX_TOKEN(lex_log_level, skip inline comment, conftext)
 }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 99 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TEQURXRULE, "=")
  yyless(strchr(conftext,'/')-conftext);
  BEGIN(PATH);
  return (TEQURXRULE);
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 106 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TSELRXRULE, "")
  yyless(strchr(conftext,'/')-conftext);
  BEGIN(PATH);
  return (TSELRXRULE);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 113 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TNEGRXRULE, "!")
  yyless(strchr(conftext,'/')-conftext);
  BEGIN(PATH);
  return (TNEGRXRULE);
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 120 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, '=', conftext)
  BEGIN(EXPR);
  return('=');
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 126 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TEXPR, conftext)
  conflval.s=checked_strdup(conftext);
  return (TEXPR);
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 132 "src/conf_lex.l"
{ /* attribute operator */
  LOG_LEX_TOKEN(lex_log_level, '+', conftext)
  return ('+');
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 137 "src/conf_lex.l"
{ /* attribute operator */
  LOG_LEX_TOKEN(lex_log_level, '-', conftext)
  return ('-');
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 142 "src/conf_lex.l"
{ /* restriction seperator */
  LOG_LEX_TOKEN(lex_log_level, ',', conftext)
  return (',');
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 147 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TVARIABLE, conftext)
  conflval.s=checked_strdup(conftext);
  BEGIN(STRINGHUNT);
  return (TVARIABLE);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 154 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TDEFINE, conftext)
  BEGIN DEFSTMT;
  return (TDEFINE);
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 160 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TUNDEFINE, conftext)
  BEGIN DEFSTMT;
  return (TUNDEFINE);
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 166 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TIF, conftext)
  BEGIN(CONDITION);
  return (TIF);
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 172 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TBOOLNOT, conftext)
  return (TBOOLNOT);
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 177 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TBOOLFUNC (BOOL_OP_DEFINED), conftext)
  conflval.operator = BOOL_OP_DEFINED;
  BEGIN(STRINGHUNT);
  return (TBOOLFUNC);
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 184 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TBOOLFUNC (BOOL_OP_HOSTNAME), conftext)
  conflval.operator = BOOL_OP_HOSTNAME;
  BEGIN(STRINGHUNT);
  return (TBOOLFUNC);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 191 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TBOOLFUNC (BOOL_OP_EXISTS), conftext)
  conflval.operator = BOOL_OP_EXISTS;
  BEGIN(STRINGHUNT);
  return (TBOOLFUNC);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 198 "src/conf_lex.l"
{
  DEPRECATION_NOTICE("@@ifdef", "@@if defined")
  LOG_LEX_TOKEN(lex_log_level, TIFDEF, conftext)
  BEGIN(STRINGHUNT);
  return (TIFDEF);
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 205 "src/conf_lex.l"
{
  DEPRECATION_NOTICE("@@ifndef", "@@if not defined")
  LOG_LEX_TOKEN(lex_log_level, TIFNDEF, conftext)
  BEGIN(STRINGHUNT);
  return (TIFNDEF);
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 212 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TELSE, conftext)
  BEGIN CONFIG;
  return (TELSE);
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 218 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TENDIF, conftext)
  BEGIN CONFIG;
  return (TENDIF);
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 224 "src/conf_lex.l"
{
  DEPRECATION_NOTICE("@@ifhost", "@@if hostname")
  LOG_LEX_TOKEN(lex_log_level, TIFHOST, conftext)
  BEGIN(STRINGHUNT);
  return (TIFHOST);
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 231 "src/conf_lex.l"
{
  DEPRECATION_NOTICE("@@ifnhost", "@@if not hostname")
  LOG_LEX_TOKEN(lex_log_level, TIFNHOST, conftext)
  BEGIN(STRINGHUNT);
  return (TIFNHOST);
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 238 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TINCLUDE, conftext)
  BEGIN(STRINGS);
  return (TINCLUDE);
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 244 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TXINCLUDE, conftext)
  BEGIN(STRINGS);
  return (TXINCLUDE);
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 250 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TSETENV, conftext)
  BEGIN ENVVAR;
  return (TSETENV);
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 256 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TVARIABLE, conftext)
  conflval.s=checked_strdup(conftext);
  BEGIN(STRINGHUNT);
  return (TVARIABLE);
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 263 "src/conf_lex.l"
{
    LOG_LEX_TOKEN(LOG_LEVEL_DEBUG, skip tab(s)/whitespace(s), conftext)
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 267 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_IN_OPTION), conftext)
  conflval.option = DATABASE_IN_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 274 "src/conf_lex.l"
{
  DEPRECATION_WARNING("database", "database_in")
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_IN_OPTION), conftext)
  conflval.option = DATABASE_IN_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 282 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_OUT_OPTION), conftext)
  conflval.option = DATABASE_OUT_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 289 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_NEW_OPTION), conftext)
  conflval.option = DATABASE_NEW_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 296 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_ATTRIBUTES_OPTION), conftext)
  conflval.option = DATABASE_ATTRIBUTES_OPTION;
  BEGIN (EXPREQUHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 303 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (WARN_DEAD_SYMLINKS_OPTION), conftext)
  conflval.option = WARN_DEAD_SYMLINKS_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 310 "src/conf_lex.l"
{
  DEPRECATION_WARNING("grouped", "report_grouped")
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_GROUPED_OPTION), conftext)
  conflval.option = REPORT_GROUPED_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 318 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_GROUPED_OPTION), conftext)
  conflval.option = REPORT_GROUPED_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 325 "src/conf_lex.l"
{
  DEPRECATION_WARNING("summarize_changes", "report_summarize_changes")
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_SUMMARIZE_CHANGES_OPTION), conftext)
  conflval.option = REPORT_SUMMARIZE_CHANGES_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 333 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_SUMMARIZE_CHANGES_OPTION), conftext)
  conflval.option = REPORT_SUMMARIZE_CHANGES_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 339 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (ACL_NO_SYMLINK_FOLLOW_OPTION), conftext)
  conflval.option = ACL_NO_SYMLINK_FOLLOW_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 346 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_FORMAT_OPTION), conftext)
  conflval.option = REPORT_FORMAT_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 353 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_LEVEL_OPTION), conftext)
  conflval.option = REPORT_LEVEL_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 360 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_IGNORE_ADDED_ATTRS_OPTION), conftext)
  conflval.option = REPORT_IGNORE_ADDED_ATTRS_OPTION;
  BEGIN (EXPREQUHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 367 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_IGNORE_REMOVED_ATTRS_OPTION), conftext)
  conflval.option = REPORT_IGNORE_REMOVED_ATTRS_OPTION;
  BEGIN (EXPREQUHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 374 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_IGNORE_CHANGED_ATTRS_OPTION), conftext)
  conflval.option = REPORT_IGNORE_CHANGED_ATTRS_OPTION;
  BEGIN (EXPREQUHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 381 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_FORCE_ATTRS_OPTION), conftext)
  conflval.option = REPORT_FORCE_ATTRS_OPTION;
  BEGIN (EXPREQUHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 388 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (VERBOSE_OPTION), conftext)
  conflval.option = VERBOSE_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 395 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (LOG_LEVEL_OPTION), conftext)
  conflval.option = LOG_LEVEL_OPTION;
  BEGIN(STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 402 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_ADD_METADATA_OPTION), conftext)
  conflval.option = DATABASE_ADD_METADATA_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 409 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_URL_OPTION), conftext)
  conflval.option = REPORT_URL_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 416 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_DETAILED_INIT_OPTION), conftext)
  conflval.option = REPORT_DETAILED_INIT_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 423 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_BASE16_OPTION), conftext)
  conflval.option = REPORT_BASE16_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 430 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_QUIET_OPTION), conftext)
  conflval.option = REPORT_QUIET_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 437 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_APPEND_OPTION), conftext)
  conflval.option = REPORT_APPEND_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 444 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (REPORT_IGNORE_E2FSATTRS_OPTION), conftext)
  conflval.option = REPORT_IGNORE_E2FSATTRS_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 451 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (DATABASE_GZIP_OPTION), conftext)
  conflval.option = DATABASE_GZIP_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 458 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (ROOT_PREFIX_OPTION), conftext)
  conflval.option = ROOT_PREFIX_OPTION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 465 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (CONFIG_VERSION), conftext)
  conflval.option = CONFIG_VERSION;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 472 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (CONFIG_CHECK_WARN_UNRESTRICTED_RULES), conftext)
  conflval.option = CONFIG_CHECK_WARN_UNRESTRICTED_RULES;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 479 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, CONFIGOPTION (NUM_WORKERS), conftext)
  conflval.option = NUM_WORKERS;
  BEGIN (STRINGEQHUNT);
  return (CONFIGOPTION);
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 486 "src/conf_lex.l"
{
  log_msg(LOG_LEVEL_ERROR,"%s:%d: unknown config option: '%s' (line: '%s')", conf_filename, conf_linenumber, conftext, conf_linebuf);
  exit(INVALID_CONFIGURELINE_ERROR);
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 491 "src/conf_lex.l"
{ /* group definition */
  conflval.s=checked_strdup(conftext);
  LOG_LEX_TOKEN(lex_log_level, TGROUP, conftext)
  BEGIN(EXPREQUHUNT);
  return (TGROUP);
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 498 "src/conf_lex.l"
{ /* group definition, deprecated group names */
  log_msg(LOG_LEVEL_WARNING, "%s:%d: special characters in group names are DEPRECATED. Update your config and only use alphanumeric characters (A-Za-z0-9) (line: '%s')", conf_filename, conf_linenumber, conf_linebuf); \
  conflval.s=checked_strdup(conftext);
  LOG_LEX_TOKEN(lex_log_level, TGROUP, conftext)
  BEGIN(EXPREQUHUNT);
  return (TGROUP);
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 506 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, '=', conftext)
  BEGIN(STRING);
  return('=');
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 512 "src/conf_lex.l"
{
  size_t length = strlen(conftext)-4;
  conflval.s=checked_malloc(length+1);
  strncpy(conflval.s, conftext+3, length);
  conflval.s[length] = '\0';
  LOG_LEX_TOKEN(lex_log_level, TVARIABLE, conflval.s)
  return (TVARIABLE);
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 521 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TSTRING, conftext)
  conflval.s=checked_strdup(conftext);
  return (TSTRING);
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 527 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, (escaped) TSTRING, conftext)
  conflval.s=checked_strdup(conftext+1);
  return (TSTRING);
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 533 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, (single-character) TSTRING, conftext)
  conflval.s=checked_strdup(conftext);
  return (TSTRING);
}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 539 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(lex_log_level, TSPACE, conftext)
  return (TSPACE);
}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 544 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(LOG_LEVEL_DEBUG, skip tab(s)/whitespace(s), conftext)
  BEGIN(CONFIG);
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 549 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(LOG_LEVEL_DEBUG, skip tab(s)/whitespace(s), conftext)
  BEGIN(EXPR);
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 554 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(LOG_LEVEL_DEBUG, skip tab(s)/whitespace(s), conftext)
  BEGIN(STRING);
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 559 "src/conf_lex.l"
{
  LOG_LEX_TOKEN(LOG_LEVEL_DEBUG, found string -> unput, conftext)
  yyless(0);
  BEGIN(STRING);
}
	YY_BREAK
case 76:
/* rule 76 can match eol */
YY_RULE_SETUP
#line 565 "src/conf_lex.l"
{
  log_msg(lex_log_level,"%s:%d: \u2534 TNEWLINE (text: '%s')", conf_filename, conf_linenumber, strlen(conftext) == 2?"\\r\\n":"\\n");
  BEGIN 0;
  return (TNEWLINE);
}
	YY_BREAK
case YY_STATE_EOF(CONFIG):
case YY_STATE_EOF(DEFSTMT):
case YY_STATE_EOF(ENVVAR):
case YY_STATE_EOF(EXPR):
case YY_STATE_EOF(EXPREQUHUNT):
case YY_STATE_EOF(PATH):
case YY_STATE_EOF(STRING):
case YY_STATE_EOF(STRINGS):
case YY_STATE_EOF(STRINGEQHUNT):
case YY_STATE_EOF(STRINGHUNT):
case YY_STATE_EOF(CONDITION):
#line 571 "src/conf_lex.l"
{
  log_msg(lex_log_level,"%s:%d: \u2534 <end of file>", conf_filename, conf_linenumber);
  log_msg(LOG_LEVEL_NOTICE,"%s:%d: missing new line at end of file (line: '%s')", conf_filename, conf_linenumber, conf_linebuf);
  return (0);
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 577 "src/conf_lex.l"
{
     char *unexpected_character = conftext;
     switch (*conftext) {
         case '\r': unexpected_character = "\\r"; break;
     };
     log_msg(LOG_LEVEL_ERROR,"%s:%d: unexpected character: '%s' (line: '%s')", conf_filename, conf_linenumber, unexpected_character, conf_linebuf);
     exit(INVALID_CONFIGURELINE_ERROR);
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 586 "src/conf_lex.l"
ECHO;
	YY_BREAK
#line 2235 "src/conf_lex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 505 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 505 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 504);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 586 "src/conf_lex.l"


int confwrap(void){
  return 1;
}

void conf_lex_string(const char * name, const char *string) {
    log_msg(LOG_LEVEL_DEBUG, "parse: '%s'", name);
    conf_linenumber = 0;
    conf_filename = checked_strdup(name); /* not to be freed, needed for logging */
    conf_scan_string(string);
}

void conf_lex_file(const char * config) {
    log_msg(LOG_LEVEL_DEBUG, "parse: '%s'", config);
    conf_linenumber = 0;

    if (strcmp(config,"-") == 0) {
        conf_filename = checked_strdup("(stdin)"); /* not to be freed, needed for logging */
        confin = stdin;
    } else {
        conf_filename = checked_strdup(config);  /* not to be freed, needed for logging */
        char *expanded_config = expand_tilde(checked_strdup(config));
        confin = fopen( expanded_config, "r" );
        if (!confin) {
            log_msg(LOG_LEVEL_ERROR,"cannot open config file '%s': %s", config, strerror(errno));
            exit(IO_ERROR);
        }
        free(expanded_config);
        expanded_config=NULL;
    }
    conf_switch_to_buffer(conf_create_buffer( confin, YY_BUF_SIZE ));
    BEGIN 0;
}

void conf_lex_delete_buffer() {
    conf_delete_buffer( YY_CURRENT_BUFFER );
}

